==> lmtpd-0.9.19.tar.gz: lmtpd-0.9.19/mod.c <==
/*
   Copyright 2000, 2001, 2002, 2003 Laurent Wacrenier

   This file is part of PLL lmtpd.

   PLL lmtpd is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation; either version 2 of the License, or
   (at your option) any later version.

   PLL lmtpd is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with PLL lmtpd; if not, write to the Free Software
   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

*/

static char const rcsid[] =
"$Id: mod.c,v 1.7 2003/02/08 00:06:20 lwa Exp $";

#include "config.h"
/*
 *  fonctions pour la commande "mod" des filtres
 */

#include <stdlib.h>
#include <string.h>
#include <ctype.h>
#include "lmtp.h"

int cmd_message(struct fstate *state, char *a) {
  if (state->mod_message) {
    free(state->mod_message);
  }
  state->mod_message=strdup(a);
  return FILTER_STOP;
}

int cmd_ok(struct fstate *state, char *a) {
  return FILTER_STOP;
}

int cmd_mod(struct fstate *state, char *a) {
  char *module = a;
  char *message;
  char *head;

  if (state->in_module)
    return FILTER_CONTINUE;

  if (state->module_path == NULL)
    return FILTER_CONTINUE;

  while(*a>=33 && *a<=126 && *a!=':' && *a!='/') a++;
  if (*a && !isspace((int)*a))
    return FILTER_CONTINUE;
  while(isspace((int)*a)) *a++=0;
  head = a;
  while(*a) {
    if (*a == ':' || isspace((int)*a)) {
      *a=0;
      break;
    }
    if (*a<33 || *a>126) {
      head = NULL;
      break;
    }
    a++;
  }
  message = mod_run(state, module);
  if (message && *message) {
    char content[MAX_USER_HEADER_LEN];
    struct headers *newh;
    purify_header(message, content, MAX_USER_HEADER_LEN);
    if (head && *head) {
      newh = setheader(state->hlevel, "%s: %s", head, content);
    } else {
      newh = setheader(state->hlevel, "X-Module-%s: %s", module, content);
    }
    if (newh) {
      newh->trace |= TRACE_ON;
      newh->next = state->hdr_delivered->next;
      state->hdr_delivered->next = newh;
      state->nbheaders++;
    }
  }
  return FILTER_CONTINUE;
}

==> lmtpd-0.10.7.tar.gz: lmtpd-0.10.7/mod.c <==
/*
   Copyright 2000, 2001, 2002, 2003 Laurent Wacrenier

   This file is part of PLL lmtpd.

   PLL lmtpd is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation; either version 2 of the License, or
   (at your option) any later version.

   PLL lmtpd is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with PLL lmtpd; if not, write to the Free Software
   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

*/

#include "config.h"

static char const rcsid[] UNUSED =
"$Id: mod.c,v 1.8 2004/10/26 09:59:20 lwa Exp $";


/*
 *  fonctions pour la commande "mod" des filtres
 */

#include <stdlib.h>
#include <string.h>
#include <ctype.h>
#include "lmtp.h"

int cmd_message(struct fstate *state, char *a) {
  if (state->mod_message) {
    free(state->mod_message);
  }
  state->mod_message=strdup(a);
  return FILTER_STOP;
}

int cmd_ok(struct fstate *state, char *a) {
  return FILTER_STOP;
}

int cmd_mod(struct fstate *state, char *a) {
  char *module = a;
  char *message;
  char *head;

  if (state->in_module)
    return FILTER_CONTINUE;

  if (state->module_path == NULL)
    return FILTER_CONTINUE;

  while(*a>=33 && *a<=126 && *a!=':' && *a!='/') a++;
  if (*a && !isspace((int)*a))
    return FILTER_CONTINUE;
  while(isspace((int)*a)) *a++=0;
  head = a;
  while(*a) {
    if (*a == ':' || isspace((int)*a)) {
      *a=0;
      break;
    }
    if (*a<33 || *a>126) {
      head = NULL;
      break;
    }
    a++;
  }
  message = mod_run(state, module);
  if (message && *message) {
    char content[MAX_USER_HEADER_LEN];
    struct headers *newh;
    purify_header(message, content, MAX_USER_HEADER_LEN);
    if (head && *head) {
      newh = setheader(state->hlevel, "%s: %s", head, content);
    } else {
      newh = setheader(state->hlevel, "X-Module-%s: %s", module, content);
    }
    if (newh) {
      newh->trace |= TRACE_ON;
      newh->next = state->hdr_delivered->next;
      state->hdr_delivered->next = newh;
      state->nbheaders++;
    }
  }
  return FILTER_CONTINUE;
}
